==> 0.4.2.tar.gz: lib/src/page/message_status/group/message_group_status_controller.dart <==
import 'package:flutter/material.dart';
import 'package:v_chat_sdk_core/v_chat_sdk_core.dart';
import 'package:v_chat_utils/v_chat_utils.dart';
import 'package:v_chat_voice_player/v_chat_voice_player.dart';

class MessageGroupStatusState {
  final List<VMessageStatusModel> seen = [];
  final List<VMessageStatusModel> deliver = [];
}

class MessageGroupStatusController
    extends ValueNotifier<MessageGroupStatusState> {
  final VBaseMessage message;

  MessageGroupStatusController(this.message)
      : super(MessageGroupStatusState()) {
    getData();
  }

  VChatLoadingState state = VChatLoadingState.ideal;
  VVoiceMessageController? voiceMessageController;

  void close() {
    voiceMessageController?.dispose();
    dispose();
  }

  VVoiceMessageController? getVoiceController(VBaseMessage message) {
    if (message is VVoiceMessage && voiceMessageController == null) {
      voiceMessageController = VVoiceMessageController(
        id: message.localId,
        audioSrc: message.data.fileSource,
        maxDuration: message.data.durationObj,
      );
      return voiceMessageController;
    } else if (message is VVoiceMessage && voiceMessageController != null) {
      return voiceMessageController;
    }
    return null;
  }

  void getData() async {
    await vSafeApiCall<MessageGroupStatusState>(
      onLoading: () {
        state = VChatLoadingState.loading;
        notifyListeners();
      },
      request: () async {
        final x = MessageGroupStatusState();
        x.seen.addAll(await VChatController.I.nativeApi.remote.room
            .getMessageStatusForGroup(
          message.roomId,
          message.id,
          isSeen: true,
        ));
        x.deliver.addAll(await VChatController.I.nativeApi.remote.room
            .getMessageStatusForGroup(
          message.roomId,
          message.id,
          isSeen: false,
        ));
        return x;
      },
      onSuccess: (response) {
        value = response;
        state = VChatLoadingState.success;
        notifyListeners();
      },
      onError: (exception, trace) {
        state = VChatLoadingState.error;
        notifyListeners();
      },
    );
  }
}

==> 1.1.0.tar.gz: lib/src/page/message_status/group/message_group_status_controller.dart <==
// Copyright 2023, the hatemragab project author.
// All rights reserved. Use of this source code is governed by a
// MIT license that can be found in the LICENSE file.

import 'package:flutter/material.dart';
import 'package:v_chat_message_page/src/v_chat/v_enums.dart';
import 'package:v_chat_sdk_core/v_chat_sdk_core.dart';
import 'package:v_chat_voice_player/v_chat_voice_player.dart';

import '../../../v_chat/v_safe_api_call.dart';

class MessageStatusState {
  final List<VMessageStatusModel> seen = [];
  final List<VMessageStatusModel> deliver = [];
}

class MessageGroupStatusController extends ValueNotifier<MessageStatusState> {
  final VBaseMessage message;

  MessageGroupStatusController(this.message) : super(MessageStatusState()) {
    getData();
  }

  VChatLoadingState state = VChatLoadingState.ideal;
  VVoiceMessageController? voiceMessageController;

  void close() {
    voiceMessageController?.dispose();
    dispose();
  }

  VVoiceMessageController? getVoiceController(VBaseMessage message) {
    if (message is VVoiceMessage && voiceMessageController == null) {
      voiceMessageController = VVoiceMessageController(
        id: message.localId,
        audioSrc: message.data.fileSource,
        maxDuration: message.data.durationObj,
      );
      return voiceMessageController;
    } else if (message is VVoiceMessage && voiceMessageController != null) {
      return voiceMessageController;
    }
    return null;
  }

  void getData() async {
    await vSafeApiCall<MessageStatusState>(
      onLoading: () {
        state = VChatLoadingState.loading;
        notifyListeners();
      },
      request: () async {
        final x = MessageStatusState();
        x.seen.addAll(await VChatController.I.roomApi.getMessageStatusForGroup(
          roomId: message.roomId,
          messageId: message.id,
          isSeen: true,
        ));
        x.deliver
            .addAll(await VChatController.I.roomApi.getMessageStatusForGroup(
          roomId: message.roomId,
          messageId: message.id,
          isSeen: false,
        ));
        return x;
      },
      onSuccess: (response) {
        value = response;
        state = VChatLoadingState.success;
        notifyListeners();
      },
      onError: (exception, trace) {
        state = VChatLoadingState.error;
        notifyListeners();
      },
    );
  }
}
